#include <WiFi.h> // Accès Wi-Fi
#include "time.h"  // Gestion du temps
#include <LiquidCrystal_I2C.h> // Interface I2C <=> LCD
#include <Adafruit_NeoPixel.h> // Pilotage des barres de led CJMCU_2812-8 

#define DATA      4  //Sortie de commande du barreau de pixels 
#define NUMPIXELS 24 //Declaration du nombre de pixels

int SWI = 2;  //Entrée du bouton de commande
int Green, Red, Blue; //Variables des couleurs
int multi = 1; //Multiplicateur de luminosité
int bkLight; //Variables de rétroéclairage


const char* ssid       = "Lzzzzzzzzzzzzzz"; // Id de la box
const char* password   = "xxxxxxxxxxxxxxxxxxxxxxx"; // Mot de passe Box

const char* ntpServer = "pool.ntp.org";
const long  gmtOffset_sec = 3600;
const int   daylightOffset_sec = 3600;

byte Pix_hour; // Variables des heures
byte Pix_min; // Variables des minutes
int Pix_sec; // Variables des secondes

LiquidCrystal_I2C lcd(0x27,16,2);  // Adresse du LCD 0x27 16 caractères 2 lignes

Adafruit_NeoPixel pixels(NUMPIXELS, DATA, NEO_GRB + NEO_KHZ800); // Format des données envoyées à la berre de led

void printLocalTime()
{
  struct tm timeinfo;
  if(!getLocalTime(&timeinfo)){
    lcd.println("Failed to obtain time");
    return;
  }
   //Affectation en variable numérique de l'extraction aux heures, minutes et secondes 
  Pix_hour = timeinfo.tm_hour;
  Pix_min = timeinfo.tm_min;
  Pix_sec = timeinfo.tm_sec;

   // Affichage de la date et heure sur le LCD
  lcd.setCursor(0,0);
  lcd.print(&timeinfo, "%A");
  lcd.setCursor(3,0);
  lcd.print(&timeinfo, " %d %B");
  lcd.setCursor(11,0);
  lcd.print(&timeinfo, " %Y");
  lcd.setCursor(1,1);
  lcd.print(&timeinfo, "   %H:%M:%S");

  }

void pixelDisplay()
{
  // Calcul des valeurs Bleues / Rouges / Verts en fonction des minutes 
  Red = (Pix_min * 4)/multi; 
  Blue = (240 / multi) - Red;
  Green = 0;

  // Flash vert aux quart d'heure
  if (((Pix_min == 15) and (Pix_sec < 2)) or ((Pix_min == 30)and (Pix_sec < 2)) or ((Pix_min == 45)and (Pix_sec < 2))) {
    Red =0;
    Blue = 0;
    Green = 200;
  }
  
  // Remise à zero des pixels à Minuit
  if ((Pix_hour == 0) and (Pix_min ==0)) {
    pixels.clear();
  }
  
  // Calcul du nombre de leds allumées égale au nombre d'heures 
  for(int i=0;i<Pix_hour;i++){
  pixels.setPixelColor(i, pixels.Color(Red,Green,Blue));
    pixels.show();
  }
  // Allumage rétro éclairage si appui sur le bouton et réglage de la violence de l'éclairage
    if (digitalRead(SWI)==1){
    lcd.backlight();
    bkLight = 0 ;
    multi++;
      if (multi > 4) {
        multi == 1;
      }
    delay (1000);
  }
}

void setup()
{
  //connection au WiFi
  lcd.printf("Connecting to %s ", ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
      delay(500);
      lcd.print(".");
  }
  lcd.println(" CONNECTED");
  
  //initialisation et emule le temps
  configTime(gmtOffset_sec, daylightOffset_sec, ntpServer);
  printLocalTime();

  //deconnection WiFi car le temps est trop long
  WiFi.disconnect(true);
  WiFi.mode(WIFI_OFF);

  // Declaration du bouton de commande en entrée
  pinMode(SWI, INPUT); 

  // initialise le lcd
  lcd.init();                       
  lcd.backlight();

  // initialise la barre de led
  pixels.begin();
}

void loop()
{
  delay(1000);
  printLocalTime();
  pixelDisplay();
  bkLight ++;
  if (bkLight > 60 ){
    lcd.noBacklight();   
  }

}
